@@ -1,7 +1,7 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.42';
+$Geo::Address::Formatter::VERSION = '1.43';
 use strict;
 use warnings;
 
@@ -102,7 +102,7 @@ sub format_address {
     #warn Dumper $rh_components;
 
     # set the aliases, unless this would overwrite something
-    foreach my $alias (keys %{$self->{component_aliases}}){
+    foreach my $alias (sort keys %{$self->{component_aliases}}){
 
         if (defined($rh_components->{$alias})
             && !defined($rh_components->{$self->{component_aliases}->{$alias}})
@@ -112,7 +112,7 @@ sub format_address {
                 $rh_components->{$alias};
         }
     }
-    #warn "after setting aliases":
+    #warn "after setting aliases";
     #warn Dumper $rh_components;
     # determine the template
     my $rh_config = $self->{templates}{uc($cc)} || $self->{templates}{default};
@@ -281,7 +281,7 @@ sub _apply_replacements {
     my $raa_rules     = shift;
 
     #warn Dumper $raa_rules;
-    foreach my $key ( keys %$rh_components ){
+    foreach my $key ( sort keys %$rh_components ){
         foreach my $ra_fromto ( @$raa_rules ){
 
             try {
@@ -333,7 +333,7 @@ sub _render_template {
 
     # is it empty?
     if ($output !~ m/\w/){
-        my @comps = keys %$components;
+        my @comps = sort keys %$components;
         if (scalar(@comps) == 1){  
             foreach my $k (@comps){
                 $output = $components->{$k};
@@ -350,7 +350,7 @@ sub _find_unknown_components {
     my $components = shift;
 
     my %h_known = map { $_ => 1 } @{ $self->{ordered_components} };
-    my @a_unknown = grep { !exists($h_known{$_}) } keys %$components;
+    my @a_unknown = grep { !exists($h_known{$_}) } sort keys %$components;
 
     #warn Dumper \@a_unknown;
     return \@a_unknown;
@@ -370,7 +370,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.42
+version 1.43
 
 =head1 SYNOPSIS
 
